Documentation
¶
Overview ¶
Package aerospike provides a testcontainer for Aerospike database.
Index ¶
- func WithEnterpriseEdition() testcontainers.CustomizeRequestOption
- func WithImage(image string) testcontainers.CustomizeRequestOption
- func WithLogLevel(logLevel string) testcontainers.CustomizeRequestOption
- func WithNamespace(namespace string) testcontainers.CustomizeRequestOption
- func WithTTLSupport(namespace string) testcontainers.CustomizeRequestOption
- type Container
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WithEnterpriseEdition ¶
func WithEnterpriseEdition() testcontainers.CustomizeRequestOption
WithEnterpriseEdition sets the image to the enterprise edition of Aerospike.
func WithImage ¶
func WithImage(image string) testcontainers.CustomizeRequestOption
WithImage sets the image for the Aerospike container.
func WithLogLevel ¶
func WithLogLevel(logLevel string) testcontainers.CustomizeRequestOption
WithLogLevel sets the log level for the Aerospike container.
func WithNamespace ¶
func WithNamespace(namespace string) testcontainers.CustomizeRequestOption
WithNamespace sets the default namespace that is created when Aerospike starts. By default, this is set to "test".
func WithTTLSupport ¶
func WithTTLSupport(namespace string) testcontainers.CustomizeRequestOption
WithTTLSupport enables TTL (time-to-live) support for records by setting nsup-period. This is required for records with explicit TTL values to expire properly. The namespace parameter specifies which namespace to configure (default: "test").
Types ¶
type Container ¶
type Container struct {
testcontainers.Container
}
Container represents a running Aerospike container.
func RunContainer ¶
func RunContainer(ctx context.Context, opts ...testcontainers.ContainerCustomizer) (*Container, error)
RunContainer creates an instance of the Aerospike container type.